Test temperature for the near space lab

Dependencies:   SDFileSystem mbed TEMP_Test

Dependents:   TEMP_Test

Fork of RGB_Test by Jeriah Bankson

Revision:
7:b8647f72947c
Parent:
4:4b67d7667474
--- a/TEMPSensor.cpp	Wed Mar 16 22:06:43 2016 +0000
+++ b/TEMPSensor.cpp	Thu Mar 31 16:34:14 2016 +0000
@@ -1,29 +1,28 @@
 #include "TEMPSensor.h"
 #include "mbed.h"
-#include "TMP102.h"
 // The location of the sensor on the FRDM-K64F//
 
-I2C i2c(PTE25,PTE24);
-TMP102 thermometerInside(i2c,0x90);
+AnalogIn thermometerInside(PTC10);
 AnalogIn thermometerOutside1(PTB3);
 AnalogIn thermometerOutside2(PTC11);
-AnalogIn thermometerPanel1(PTB10);
-AnalogIn thermometerPanel2(PTC10);
+AnalogIn thermometerPanel(PTB10);
 
 float get_outsideTemp()//function to return temperature readings from outside thermometers not in contact with the panels
 {
-    float outsideTemp = (thermometerOutside1.read()+ thermometerOutside2.read()) / 2; //average of two outside thermometer
-    return outsideTemp;
+    float readOne = thermometerOutside1.read();
+    float readTwo = thermometerOutside2.read();
+    float outsideTemp = ( readTwo + readOne ) / 2; //average of two outside thermometer
+    return ( outsideTemp * 100 ); //conversion to celcius
 }
 
-float get_insideTemp()//function to return data from inside on-boatd thermometer
+float get_insideTemp()//function to return data from inside thermometer
 {
     float insideTemp = thermometerInside.read(); // onboard in-pod thermometer
-    return insideTemp;
+    return ( insideTemp * 100 ) ; //conversion to celcius
  }       
 
-float get_panelTemp()//function to return data from the thermometers in contact with the solar panels
+float get_panelTemp()//function to return data from the thermometer in contact with the solar panels
 {   
-    float panelTemp = (thermometerPanel1.read() + thermometerPanel2.read()) / 2; // average of two on-panel thermometer
-    return panelTemp;
+    float panelTemp = thermometerPanel.read(); // on-panel thermometer
+    return ( panelTemp *100 ); // conversion to celcius
 }
\ No newline at end of file